## Doc types

* [ ] Extract `how to` documents from code.
* [ ] Extract `step by step guide` from code.
* [ ] Extract Developer guide form code.
* [ ] Extract architecture and ERD form code.
* [ ] Extract `API documentation` from code.
* [ ] Extract `Tutorials` from code.
* [ ] Extract `Glossary` from code.
* [ ] Extract `Release notes` from code and git history.
* [ ] Extract `Changelog` from code and git history.
* [ ] Extract `Contributing guide` from code.
* [ ] Generate `README.md` file.

## Features

* [ ] 2 interactive modes: developer and user. That can be determined with `--mode` flag.
* [ ] Running a local model built-in instead of OpenRouter.
* [ ] Running on CI/CD pipelines and update the docs based on code changes.
